@@ -1,10 +1,10 @@
 from typing import List, Sequence, TypeVar, Union, overload
 
-T = TypeVar("T")
+_T = TypeVar("_T")
 
 
-class gather(Sequence[T]):
-    def __init__(self, sequence: Sequence[T], indices: Sequence[int]):
+class gather(Sequence[_T]):
+    def __init__(self, sequence: Sequence[_T], indices: Sequence[int]):
         self._sequence = sequence
         self._indices = indices
 
@@ -12,14 +12,14 @@ class gather(Sequence[T]):
         return len(self._indices)
 
     @overload
-    def __getitem__(self, index: int) -> T:
+    def __getitem__(self, index: int) -> _T:
         ...
 
     @overload
-    def __getitem__(self, index: slice) -> List[T]:
+    def __getitem__(self, index: slice) -> List[_T]:
         ...
 
-    def __getitem__(self, index: Union[int, slice]) -> Union[T, List[T]]:
+    def __getitem__(self, index: Union[int, slice]) -> Union[_T, List[_T]]:
         if isinstance(index, int):
             return self._sequence[self._indices[index]]
         return [self._sequence[i] for i in self._indices[index]]
